import { Component, OnInit } from '@angular/core';
import { Router, ActivatedRoute, Params } from '@angular/router';
import { UserService } from '../services/user.service';
import { GLOBAL } from '../services/global';
import { Sport } from '../models/sport';
import { Game } from '../models/game';
import { GameService } from '../services/game.service';
import { StatusGame } from '../models/statusGame';
import { SportService } from '../services/sport.service';
import { CategoryService } from '../services/category.service';
import { Category } from '../models/category';
import { Time } from '@angular/common';
import { TeamService } from '../services/team.service';
import { Team } from '../models/team';
import { Participation } from '../models/participation';
import { ParticipationService } from '../services/participation.service';
@Component({
    selector: 'game-detail',
    templateUrl: '../views/game-detail.html',
    providers: [UserService,GameService,SportService,CategoryService,GameService,TeamService,ParticipationService]
})

export class GameDetailComponent implements OnInit{
    public titulo:string;
    public game:Game;
    public sport:Sport;
    public category:Category;
    public teams:Team[];
    public teamsTotales:Team[];
    public participations:Participation[];
    public identity;
    public token;
    public url:string;
    public alertMessage;
    public status;
    public zoom;
    public addTeam=false;
    public confirmado;


    constructor(
        private _userService:UserService,
        private _sportService:SportService,
        private _categoryService:CategoryService,
        private _gameService:GameService,
        private _router:Router,
        private _route:ActivatedRoute,
        private _teamService:TeamService,
        private _participationService:ParticipationService
    ){  
        var lat=40.64259556067634;
        var lng=-3.963626378625804;
        this.game = new Game('','',null,'','','',null,null,null,null);
        this.sport=new Sport('','',null,'','');
        this.category=new Category('','','',null);
        this.game.location={lat:lat,lng:lng}
        this.identity = this._userService.getIdentity();
        this.token = this._userService.getToken();
        this.url = GLOBAL.url;
        this.zoom=12;
    }

    ngOnInit(){
        this.getGame();
        
    }

    getGame(){
        this._route.params.forEach((params:Params)=>{
            let id = params['id'];

            this._gameService.getGame(this.token,id).subscribe(
                response=>{
                    if(!response.game){
                        this._router.navigate(['/']);
                    }else{
                        this.game=response.game;
                        this.category= response.game.category;
                        this.sport=response.game.category.sport;
                        this.game.dateStart = new Date(this.game.dateStart);
                        this.getTeamsFromSport();
                    }
                },
                error=>{
                    var errorMessage = <any>error;
                    if(errorMessage!=null){
                        var body = JSON.parse(error._body);
                        //this.alertMessage=body.message;
                    }
                }
            )
        });
    }

    getTeamsFromSport(){
        this._teamService.getTeamsBySport(this.token ,this.sport._id).subscribe(
            response=>{
                if(!response.teams){
                    
                }else{
                    this.teamsTotales = response.teams;
                    this.getParticipations();
                }
            },
            error=>{
                var errorMessage = <any>error;
                if(errorMessage!=null){
                    console.log(error);
                    //var body = JSON.parse(error._body);
                    //this.alertMessage=body.message;
                }
            }
        )
    }

    createTeam(){
        this.addTeam=true;
    }

    addParticipation(team:Team){
        if(!this.participations){
            this.participations = [];
        }
        if(this.sport.maxTeams>this.participations.length){
            var numberOfGame;
            for(var i=0;i<this.participations.length+1;i++){
                var numeroCogido=false;
                for(var j=0;j<this.participations.length;j++){
                    if((i+1)==this.participations[j].numberTeam){
                        numeroCogido=true;
                    }
                }
                if(!numeroCogido){
                    numberOfGame=i+1;
                    break;
                }
                
            }
            
            if(numberOfGame==null){
                numberOfGame = this.participations.length;
            }

            var participation = new Participation('',team._id,this.game._id,numberOfGame,team);
            this._participationService.addParticipation(this.token, participation).subscribe(
                response=>{
                    if(!response.participation){
                        
                    }else{
                        this.getParticipations();
                    }
                },
                error=>{
                    var errorMessage = <any>error;
                    if(errorMessage!=null){
                        console.log(error);
                        //var body = JSON.parse(error._body);
                        //this.alertMessage=body.message;
                    }
                }
            )
        }else{
            this.alertMessage = "No se puede añadir mas equipos porque el número máximo de participantes es:"+this.sport.maxTeams;
        }
    }

    getParticipations(){
        this._participationService.getParticipationsGame(this.token,this.game._id).subscribe(
            response=>{
                if(!response.participations){
                    this.teams= this.teamsTotales;
                }else{
                    this.participations = response.participations;
                    for(var i=0;i<this.participations.length;i++){
                        var params = response.participations[i];
                        this.participations[i].teamModelo= response.participations[i].team;
                        this.participations[i].team=response.participations[i].team._id;
                    }
                    this.removeTeamsPartipation();
                }
            },
            error=>{
                var errorMessage = <any>error;
                if(errorMessage!=null){
                    
                    this.teams= this.teamsTotales;
                    console.log(error);
                    //var body = JSON.parse(error._body);
                    //this.alertMessage=body.message;
                }
            }
        )
    }

    removeTeamsPartipation(){
        for(var i=0;i<this.participations.length;i++){
            for(var j=0;j<this.teamsTotales.length;j++){
                if(this.participations[i].teamModelo._id==this.teamsTotales[j]._id){
                    this.teamsTotales.splice(j,1);
                }
            }
        }
        this.teams= this.teamsTotales;
    }

    onDeleteParticipation(id){
        this.confirmado=id;
    }

    onCancelParticipation(){
        this.confirmado='';
    }

    onDeleteParticipationConfirm(id){
        this._participationService.deleteParticipation(this.token,id).subscribe(
            response =>{
                if(!response.participation){
                    this._router.navigate(['/']);
                }else{
                    this.getTeamsFromSport();

                    this.confirmado='';
                }
            },
            error=>{
                var errorMessage = <any>error;
                if(errorMessage!=null){
                    var body = JSON.parse(error._body);
                }
            }
        )
    }
}