import { Component, OnInit } from '@angular/core';
import { Router, ActivatedRoute, Params } from '@angular/router';
import { UserService } from '../services/user.service';
import { GLOBAL } from '../services/global';
import { Sport } from '../models/sport';
import { Game } from '../models/game';
import { GameService } from '../services/game.service';
import { StatusGame } from '../models/statusGame';
import { SportService } from '../services/sport.service';
import { CategoryService } from '../services/category.service';
import { Category } from '../models/category';
import { Time } from '@angular/common';

@Component({
    selector: 'game-add',
    templateUrl: '../views/game-add.html',
    providers: [UserService,GameService,SportService,CategoryService,GameService]
})

export class GameEditComponent implements OnInit{
    public titulo:string;
    public game:Game;
    public sports:Sport[];
    public categories:Category[];
    public identity;
    public token;
    public url:string;
    public alertMessage;
    public status;
    public zoom;
    public lat:number;
    public lng:number;
    public activedGames:boolean;
    public is_edit;
    public hora:string;


    constructor(
        private _userService:UserService,
        private _sportService:SportService,
        private _categoryService:CategoryService,
        private _gameService:GameService,
        private _router:Router,
        private _route:ActivatedRoute,
    ){
        this.lat=40.64259556067634;
        this.lng=-3.963626378625804;
        this.game = new Game('','',null,'','','',null,null,null,null);
        this.game.location={lat:this.lat,lng:this.lng}
        this.titulo = 'Editar partido';
        this.game.status= StatusGame.sinempezar;
        this.identity = this._userService.getIdentity();
        this.game.broadcaster=this.identity._id;
        this.token = this._userService.getToken();
        this.url = GLOBAL.url;
        this.zoom=12;
        this.is_edit=true;
    }

    ngOnInit(){
        this.getGame();
        this.getStatus();
        this.getSports();
    }

    getStatus(){
      var status= Object.keys(StatusGame);
      this.status=status;
    }

    getSports(){
        this._sportService.getAllSports(this.token).subscribe(
            response =>{
                if(!response.sports){
                }else{
                    this.sports=response.sports;
                }
            },
            error=>{
                var errorMessage = <any>error;
                if(errorMessage!=null){
                    var body = JSON.parse(error._body);
                    console.log(error);
                }
            }
        )
    }

    getGame(){
        this._route.params.forEach((params:Params)=>{
            let id = params['id'];

            this._gameService.getGame(this.token,id).subscribe(
                response=>{
                    if(!response.game){
                        this._router.navigate(['/']);
                    }else{
                        this.game=response.game;
                        this.game.sport=response.game.category.sport;
                        this.sportChange();
                        this.game.dateStart = new Date(this.game.dateStart);
                    }
                },
                error=>{
                    var errorMessage = <any>error;
                    if(errorMessage!=null){
                        var body = JSON.parse(error._body);
                        //this.alertMessage=body.message;
                    }
                }
            )
        });
    }

    mapClicked($event:any){
        this.game.location.lat= $event.coords.lat;
        this.game.location.lng=$event.coords.lng;
    }

    sportChange(){
        this._categoryService.getCategories(this.token,this.game.sport).subscribe(
            response =>{
                if(!response.categories){
                }else{
                    this.categories=response.categories;
                }
            },
            error=>{
                var errorMessage = <any>error;
                if(errorMessage!=null){
                    var body = JSON.parse(error._body);
                    console.log(error);
                }
            }
        );
    }


    timeChange(){
        var horas =this.hora.split(':');
        this.game.dateStart = new Date(this.game.dateStart);
        this.game.dateStart.setHours(parseInt(horas[0]));
        this.game.dateStart.setMinutes(parseInt(horas[1]));
    }

    onSubmit(){
        this._gameService.editGame(this.token,this.game._id,this.game).subscribe(
            response =>{
                if(!response.game){
                    this.alertMessage='Error en el servidor';
                }else{
                    this.game=response.game;
                    this.alertMessage='El deporte se ha creado correctamente!';
                    this._router.navigate(['/partidos']);
                }

            },
            error=>{
                var errorMessage = <any>error;
                if(errorMessage!=null){
                    var body = JSON.parse(error._body);
                    this.alertMessage=body.message;
                    console.log(error);
                }
            }
        );
    }
}