import { Component, OnInit } from '@angular/core';
import { Router, ActivatedRoute, Params } from '@angular/router';
import { UserService } from '../services/user.service';
import { GLOBAL,getStatusString } from '../services/global';
import { Sport } from '../models/sport';
import { SportService } from '../services/sport.service';
import { GameService } from '../services/game.service';
import { Game } from '../models/game';
import { Participation } from '../models/participation';
import { ParticipationService } from '../services/participation.service';
import { StatusGame } from '../models/statusGame';

@Component({
    selector: 'game-list',
    templateUrl: '../views/game-list.html',
    providers: [UserService,SportService,GameService,ParticipationService]
})

export class GameListComponent implements OnInit{
    public titulo:string;
    public identity;
    public token;
    public url:string;
    public confirmado;
    public games:Game[];
    public activeGame:Game;
    public StatusGame=StatusGame;

    constructor(
        private _route:ActivatedRoute,
        private _router:Router,
        private _userService:UserService,
        private _sportService:SportService,
        private _gameService:GameService,
        private _participationService:ParticipationService
    ){
        this.titulo = 'Partidos';
        this.identity = this._userService.getIdentity();
        this.token = this._userService.getToken();
        this.url = GLOBAL.url;
    }

    ngOnInit(){
        this.getGames();
        this.getActiveGame();
    }

    getGames(){
        this._gameService.getGames(this.token,this.identity._id).subscribe(
            response =>{
                if(!response.games){
                    this._router.navigate(['/']);
                }else{
                   this.games=response.games;
                }
            },
            error=>{
                var errorMessage = <any>error;
                if(errorMessage!=null){
                    var body = JSON.parse(error._body);
                    console.log(error);
                }
            }
        );
    }

    getActiveGame(){
        this._gameService.getActiveGame(this.token,this.identity._id).subscribe(
            response =>{
                if(!response.game){
                    this._router.navigate(['/']);
                }else{
                    this.activeGame = response.game[0];
                    this._participationService.getParticipationsGame(this.token,this.activeGame._id).subscribe(
                        response =>{
                            if(!response.participations){
                                this.activeGame=null;
                            }else{
                                this.activeGame.participations = response.participations;
                            }
                        },
                        error=>{
                            var errorMessage = <any>error;
                            if(errorMessage!=null){
                                var body = JSON.parse(error._body);
                                console.log(error);
                            }
                        }
                    )
                }
            },
            error=>{
                var errorMessage = <any>error;
                if(errorMessage!=null){
                    var body = JSON.parse(error._body);
                }
            }
        );
    }
    onDeleteGame(id){
        this.confirmado=id;
    }

    onCancelGame(){
        this.confirmado='';
    }

    onDeleteGameConfirm(id){
        this._gameService.deleteGame(this.token,id).subscribe(
            response =>{
                if(!response.game){
                    this._router.navigate(['/']);
                }else{
                    if(response.game._id==this.activeGame._id){
                        this.activeGame=null;
                    }else{
                        this.getGames();
                    }
                }
            },
            error=>{
                var errorMessage = <any>error;
                if(errorMessage!=null){
                    var body = JSON.parse(error._body);
                }
            }
        )
    }
}