import { Component, OnInit } from '@angular/core';
import { Router, ActivatedRoute, Params } from '@angular/router';
import { UserService } from '../services/user.service';
import { GLOBAL } from '../services/global';
import { Sport } from '../models/sport';
import { SportService } from '../services/sport.service';
import { UploadService } from '../services/upload.service';

@Component({
    selector: 'sport-add',
    templateUrl: '../views/sport-add.html',
    providers: [UserService,SportService,UploadService]
})

export class SportAddComponent implements OnInit{
    public titulo:string
    public sport: Sport;
    public identity;
    public token;
    public url:string;
    public alertMessage;
    public filesToUpload: Array<File>;

    constructor(
        private _route:ActivatedRoute,
        private _router:Router,
        private _userService:UserService,
        private _sportService:SportService,
        private _uploadService:UploadService
    ){
        this.sport = new Sport('','',null,'','');
        this.titulo = 'Crear nuevo deporte';
        this.identity = this._userService.getIdentity();
        this.token = this._userService.getToken();
        this.url = GLOBAL.url;
    }

    ngOnInit(){

    }

    onSubmit(){
        if(this.filesToUpload){
            this._sportService.addSport(this.token,this.sport).subscribe(
                response =>{
                    if(!response.sport){
                        this.alertMessage='Error en el servidor';
                    }else{
                        this.sport=response.sport;
                        console.log(this.sport);
                        this._uploadService.makeFileRequest(this.url+'upload-image-sport/'+this.sport._id,[],this.filesToUpload,this.token,'image').then(
                            (result)=>{
                                this._router.navigate(['/editar-deporte',this.sport._id]);
                            },
                            (error)=>{
                                console.log(error);
                            }
                        );
                        this.alertMessage='El deporte se ha creado correctamente!';
                        this.sport=response.sport;
                        this._router.navigate(['/editar-deporte'],response.sport._id);
                    }
    
                },
                error=>{
                    var errorMessage = <any>error;
                    if(errorMessage!=null){
                        var body = JSON.parse(error._body);
                        this.alertMessage=body.message;
                        console.log(error);
                    }
                }
            );
        }
    }

    fileChangeEvent(fileInput: any){
        this.filesToUpload = <Array<File>>fileInput.target.files;
    }
}
