import { Component, OnInit } from '@angular/core';
import { Router, ActivatedRoute, Params } from '@angular/router';
import { UserService } from '../services/user.service';
import { GLOBAL } from '../services/global';
import { Sport } from '../models/sport';
import { SportService } from '../services/sport.service';
import { RuleService } from '../services/rule.service';
import { Rule } from '../models/rule';
import { Category } from '../models/category';
import { CategoryService } from '../services/category.service';

@Component({
    selector: 'sport-detail',
    templateUrl: '../views/sport-detail.html',
    providers: [UserService,SportService,RuleService,CategoryService]
})

export class SportDetailComponent implements OnInit{
    public titulo:string;
    public sport: Sport;
    public rule: Rule;
    public rules: Rule[];
    public category: Category;
    public categories: Category[];
    public identity;
    public token;
    public url:string;
    public alertMessage;
    public filesToUpload: Array<File>;
    public confirmado;
    public addRule;
    public addCategory;

    constructor(
        private _route:ActivatedRoute,
        private _router:Router,
        private _userService:UserService,
        private _sportService:SportService,
        private _ruleService:RuleService,
        private _categoryService:CategoryService
    ){
        this.identity = this._userService.getIdentity();
        this.token = this._userService.getToken();
        this.addRule=false;
        this.addCategory=false;
        this.url = GLOBAL.url;
    }

    ngOnInit(){
        this.getSport();
    }

    getSport(){
        this._route.params.forEach((params:Params)=>{
            let id = params['id'];

            this._sportService.getSport(this.token,id).subscribe(
                response=>{
                    if(!response.sport){
                        this._router.navigate(['/']);
                    }else{
                        this.sport=response.sport;
                        //Get categorias y reglas
                        this.getRules();
                        this.getCategories();
                       
                    }
                },
                error=>{
                    var errorMessage = <any>error;
                    if(errorMessage!=null){
                        var body = JSON.parse(error._body);
                        //this.alertMessage=body.message;
                    }
                }
            )
        });
    }

    
    onDeleteConfirm(id){
        this.confirmado = id;
    }

    onDeleteCategoryConfirm(id){
        this.confirmado = id;
    }

    onCancelRule(){
        this.confirmado=null;
    }

    onCancelCategory(){
        this.confirmado=null;
    }

    onDeleteRule(id){
        this._ruleService.deleteRule(this.token,id).subscribe(
            response=>{
                if(!response.rule){
                    alert('Error en el servidor')
                }else{
                    this.getRules();
                }
                
            },
            error=>{
                var errorMessage = <any>error;
                if(errorMessage!=null){
                    var body = JSON.parse(error._body);
                   // this.alertMessage=body.message;
              }
            }
        )
    }

    onDeleteCategory(id){
        this._categoryService.deleteCategory(this.token,id).subscribe(
            response=>{
                if(!response.category){
                    alert('Error en el servidor')
                }else{
                    this.getCategories();
                }
                
            },
            error=>{
                var errorMessage = <any>error;
                if(errorMessage!=null){
                    var body = JSON.parse(error._body);
                   // this.alertMessage=body.message;
              }
            } 
        )
    }

    

    getRules(){
        this._ruleService.getRules(this.token,this.sport._id).subscribe(
            response=>{
                if(!response.rules){
                    
                }else{
                    this.rules=response.rules;
                    //Get categorias y reglas

                }
            },
            error=>{
                var errorMessage = <any>error;
                if(errorMessage!=null){
                    var body = JSON.parse(error._body);
                    //this.alertMessage=body.message;
                }
            }
        )
    }

    getCategories(){
        this._categoryService.getCategories(this.token,this.sport._id).subscribe(
            response=>{
                if(!response.categories){
                    
                }else{
                    this.categories=response.categories;
                    //Get categorias y reglas

                }
            },
            error=>{
                var errorMessage = <any>error;
                if(errorMessage!=null){
                    var body = JSON.parse(error._body);
                    //this.alertMessage=body.message;
                }
            }
        )
    }

    createRule(){
        this.resetRule();
        this.addRule=true;
    }

    createCategory(){
        this.resetCategory();
        this.addCategory=true;
    }

    editRule(rule:Rule){
        this.rule= new Rule(rule._id,rule.description,rule.sport);
        this.addRule=true;
    }

    editCategory(category:Category){
        this.category= new Category(category._id,category.categoryType,category.sport,category.pro);
        this.addCategory=true;
    }

    cancelEditRule(){
        this.resetRule();
        this.addRule=false;
    }

    cancelEditCategory(){
       this.resetCategory();
        this.addCategory=false;
    }

    resetCategory(){
        this.category= new Category('','',this.sport._id,false);
    }

    resetRule(){
        this.rule = new Rule('','',this.sport._id);
    }

    onSubmitEditRule(){
        this._ruleService.editRule(this.token,this.rule._id,this.rule).subscribe(
            response=>{
                if(!response.rule){
                    
                }else{
                    this.getRules();
                    this.resetRule();
                    this.addRule=false;
                }
            },
            error=>{
                var errorMessage = <any>error;
                if(errorMessage!=null){
                    var body = JSON.parse(error._body);
                }
            }
        )
    }

    onSubmitEditCategory(){
        this._categoryService.editCategory(this.token,this.category._id,this.category).subscribe(
            response=>{
                if(!response.category){
                    
                }else{
                    this.getCategories();
                    this.resetCategory();
                    this.addCategory=false;
                }
            },
            error=>{
                var errorMessage = <any>error;
                if(errorMessage!=null){
                    var body = JSON.parse(error._body);
                }
            }
        )
    }

    onSubmitRule(){
        this._ruleService.addRule(this.token,this.rule).subscribe(
            response=>{
                if(!response.rule){
                    
                }else{
                    this.getRules();
                    this.resetRule();
                }
            },
            error=>{
                var errorMessage = <any>error;
                if(errorMessage!=null){
                    var body = JSON.parse(error._body);
                }
            }
        )
    }

    onSubmitCategory(){
        this._categoryService.addCategory(this.token,this.category).subscribe(
            response=>{
                if(!response.category){
                    
                }else{
                    this.getCategories();
                    this.resetCategory();
                }
            },
            error=>{
                var errorMessage = <any>error;
                if(errorMessage!=null){
                    var body = JSON.parse(error._body);
                }
            }
        )
    }
}
