import { Component, OnInit } from '@angular/core';
import { Router, ActivatedRoute, Params } from '@angular/router';
import { UserService } from '../services/user.service';
import { GLOBAL } from '../services/global';
import { Sport } from '../models/sport';
import { SportService } from '../services/sport.service';

@Component({
    selector: 'sport-list',
    templateUrl: '../views/sport-list.html',
    providers: [UserService,SportService]
})

export class SportListComponent implements OnInit{
    public titulo:string
    public sports: Sport[];
    public identity;
    public token;
    public url:string
    public next_page;
    public prev_page;
    public confirmado;


    constructor(
        private _route:ActivatedRoute,
        private _router:Router,
        private _userService:UserService,
        private _sportService:SportService
    ){
        this.titulo = 'Deportes';
        this.identity = this._userService.getIdentity();
        this.token = this._userService.getToken();
        this.url = GLOBAL.url;
        this.next_page=1;
        this.prev_page=1;
    }

    ngOnInit(){
        this.getSports();
    }

    getSports(){
        this._route.params.forEach((params:Params)=>{
            let page = +params['page'];
            if(!page){
                page=1
            }else{
            }
            this._sportService.getSports(this.token,page).subscribe(
                response =>{
                    if(!response.sports){
                        this._router.navigate(['/']);
                    }else{
                        this.sports = response.sports;
                        if(response.totalItems/8<=page){
                            this.next_page = page;
                        }else{
                            this.next_page = page+1;
                        }
                        
                        this.prev_page=page-1;
                        if(this.prev_page==0){
                            this.prev_page=1;
                        }
                    }
                },
                error=>{
                    var errorMessage = <any>error;
                    if(errorMessage!=null){
                        var body = JSON.parse(error._body);
                        console.log(error);
                    }
                }
            )
        });
    }

    onDeleteSport(id){
        this.confirmado=id;
    }

    onCancelSport(){
        this.confirmado='';
    }

    onDeleteSportConfirm(id){
        this._sportService.deleteSport(this.token,id).subscribe(
            response =>{
                if(!response.sport){
                    this._router.navigate(['/']);
                }else{
                    this.getSports();
                }
            },
            error=>{
                var errorMessage = <any>error;
                if(errorMessage!=null){
                    var body = JSON.parse(error._body);
                }
            }
        )
    }
}
