import { Component, OnInit } from '@angular/core';
import { Router, ActivatedRoute, Params } from '@angular/router';
import { UserService } from '../services/user.service';
import { GLOBAL } from '../services/global';
import { TeamService } from '../services/team.service';
import { Team } from '../models/team';
import { SportService } from '../services/sport.service';
import { Sport } from '../models/sport';

@Component({
    selector: 'team-add',
    templateUrl: '../views/team-add.html',
    providers: [UserService,TeamService,SportService]
})

export class TeamAddComponent implements OnInit{
    public titulo:string;
    public team:Team;
    public identity;
    public token;
    public url:string;
    public alertMessage;
    public sports:Sport[]
    public filesToUpload: Array<File>;

    constructor(
        private _route:ActivatedRoute,
        private _router:Router,
        private _userService:UserService,
        private _teamService:TeamService,
        private _sportService:SportService
    ){
        this.team = new Team('','','','','','');
        this.titulo = 'Crear nuevo equipo';
        this.identity = this._userService.getIdentity();
        this.token = this._userService.getToken();
        this.url = GLOBAL.url;
    }

    ngOnInit(){
        this.getSports();
    }

    getSports(){
        this._sportService.getAllSports(this.token).subscribe(
            response =>{
                if(!response.sports){
                    this.alertMessage='Error en el servidor';
                }else{
                    this.sports= response.sports;
                }

            },
            error=>{
                var errorMessage = <any>error;
                if(errorMessage!=null){
                    var body = JSON.parse(error._body);
                    this.alertMessage=body.message;
                    console.log(error);
                }
            }
        )
    }

    onSubmit(){
        console.log(this.team);
        this._teamService.addTeam(this.token,this.team).subscribe(
            response =>{
                if(!response.team){
                    this.alertMessage='Error en el servidor';
                }else{
                    this.team=response.team;
                }

            },
            error=>{
                var errorMessage = <any>error;
                if(errorMessage!=null){
                    var body = JSON.parse(error._body);
                    this.alertMessage=body.message;
                    console.log(error);
                }
            }
        );
    }
}
