import { Component, OnInit } from '@angular/core';
import { Router, ActivatedRoute, Params } from '@angular/router';
import { UserService } from '../services/user.service';
import { GLOBAL } from '../services/global';
import { TeamService } from '../services/team.service';
import { Team } from '../models/team';
import { SportService } from '../services/sport.service';
import { Sport } from '../models/sport';
import { UploadService } from '../services/upload.service';

@Component({
    selector: 'team-edit',
    templateUrl: '../views/team-add.html',
    providers: [UserService,TeamService,SportService,UploadService]
})

export class TeamEditComponent implements OnInit{
    public titulo:string;
    public team:Team;
    public identity;
    public token;
    public url:string;
    public alertMessage;
    public sports:Sport[]
    public filesToUpload: Array<File>;
    public is_edit=true;

    constructor(
        private _route:ActivatedRoute,
        private _router:Router,
        private _userService:UserService,
        private _teamService:TeamService,
        private _sportService:SportService,
        private _uploadService:UploadService
    ){
        this.team = new Team('','','','','','');
        this.titulo = 'Editar equipo';
        this.identity = this._userService.getIdentity();
        this.token = this._userService.getToken();
        this.url = GLOBAL.url;
    }

    ngOnInit(){
        this.getSports();
        this.getTeam();
    }

    getSports(){
        this._sportService.getAllSports(this.token).subscribe(
            response =>{
                if(!response.sports){
                    this.alertMessage='Error en el servidor';
                }else{
                    this.sports= response.sports;
                }

            },
            error=>{
                var errorMessage = <any>error;
                if(errorMessage!=null){
                    var body = JSON.parse(error._body);
                    this.alertMessage=body.message;
                    console.log(error);
                }
            }
        )
    }

    getTeam(){
        this._route.params.forEach((params:Params)=>{
            let id = params['id'];
            this._teamService.getTeam(this.token,id).subscribe(
                response=>{
                    if(!response.team){
                        this._router.navigate(['/'])
                    }else{
                        this.team = response.team;
                    }
                },
                error=>{
                    var errorMessage = <any>error;
                    if(errorMessage!=null){
                        var body = JSON.parse(error._body);
                        console.log(error);
                        // this.alertMessage=body.message;;
                    }
                }
            );
        });
    }

    onSubmit(){
        this._teamService.editTeam(this.token,this.team._id,this.team).subscribe(
            response =>{
                if(!response.team){
                    this.alertMessage='Error en el servidor';
                }else{
                    if(this.filesToUpload && this.filesToUpload.length>0){
                        this._uploadService.makeFileRequest(this.url+'update-image-team/'+this.team._id,[],this.filesToUpload,this.token,'image').then(
                            (result)=>{
                                this._router.navigate(['/equipos',1]);
                            },
                            (error)=>{
                                console.log(error);
                            }
                        );
                    }else{
                        this.alertMessage='Deporte actualizado';
                    }
                }
            },
            error=>{
                var errorMessage = <any>error;
                if(errorMessage!=null){
                    var body = JSON.parse(error._body);
                    this.alertMessage=body.message;
                    console.log(error);
                }
            }
        );
    }

    fileChangeEvent(fileInput: any){
        this.filesToUpload = <Array<File>>fileInput.target.files;
    }
}
