import { Component, OnInit } from '@angular/core';
import { Router, ActivatedRoute, Params } from '@angular/router';
import { UserService } from '../services/user.service';
import { GLOBAL } from '../services/global';
import { Team } from '../models/team';
import { TeamService } from '../services/team.service';

@Component({
    selector: 'team-list',
    templateUrl: '../views/team-list.html',
    providers: [UserService,TeamService]
})

export class TeamListComponent implements OnInit{
    public titulo:string
    public teams: Team[];
    public identity;
    public token;
    public url:string
    public next_page;
    public prev_page;
    public confirmado;


    constructor(
        private _route:ActivatedRoute,
        private _router:Router,
        private _userService:UserService,
        private _teamService:TeamService
    ){
        this.titulo = 'Equipos';
        this.identity = this._userService.getIdentity();
        this.token = this._userService.getToken();
        this.url = GLOBAL.url;
        this.next_page=1;
        this.prev_page=1;
    }

    ngOnInit(){
        this.getTeams();
    }

    getTeams(){
        this._route.params.forEach((params:Params)=>{
            let page = +params['page'];
            if(!page){
                page=1
            }else{
            }
            this._teamService.getTeams(this.token,page).subscribe(
                response =>{
                    if(!response.teams){
                        this._router.navigate(['/']);
                    }else{
                        this.teams = response.teams;
                        if(response.totalItems/8<=page){
                            this.next_page = page;
                        }else{
                            this.next_page = page+1;
                        }
                        
                        this.prev_page=page-1;
                        if(this.prev_page==0){
                            this.prev_page=1;
                        }
                    }
                },
                error=>{
                    var errorMessage = <any>error;
                    if(errorMessage!=null){
                        var body = JSON.parse(error._body);
                        console.log(error);
                    }
                }
            )
        });
    }

    onDeleteTeam(id){
        this.confirmado=id;
    }

    onCancelTeam(){
        this.confirmado='';
    }

    onDeleteTeamConfirm(id){
        this._teamService.deleteTeam(this.token,id).subscribe(
            response =>{
                if(!response.team){
                    this._router.navigate(['/']);
                }else{
                    this.getTeams();
                }
            },
            error=>{
                var errorMessage = <any>error;
                if(errorMessage!=null){
                    var body = JSON.parse(error._body);
                }
            }
        )
    }
}
