import { Component, OnInit } from '@angular/core';

import { GLOBAL } from '../services/global';
import { UserService } from '../services/user.service';
import { User } from '../models/user';
import { TelegramData } from '../models/telegramData';

@Component({
    selector: 'user-edit',
    templateUrl: '../views/user-edit.html',
    providers: [UserService]
})

export class UserEditComponent implements OnInit{
    public titulo: string;
    public user: User;
    public telegramData: TelegramData;
    public identity;
    public tokenGenerated;
    public token;
    public alertMessage;
    public url:string;
    public filesToUpload: Array<File>;
    public telegramDataConfirmed: TelegramData;

    constructor(
        private _userService:UserService
    ){
        this.titulo='Actualizar mis datos';
        this.tokenGenerated=false;
        this.identity = this._userService.getIdentity();
        this.token = this._userService.getToken();
        this.user = this.identity;
        this.telegramData= new TelegramData('',null,'',null,'null');
        this.telegramDataConfirmed= new TelegramData('',null,'',null,'null');
        this.url = GLOBAL.url;
    }

    ngOnInit(){
        console.log('user-edit.component.ts cargado');
    }

    onSubmit(){

        this._userService.updateUser(this.user).subscribe(
            response=>{
                if(!response.user){
                    this.alertMessage='El usuario no se ha actualizado';
                }else{
                    //this.user = response.user;
                    localStorage.setItem('identity',JSON.stringify(this.user));
                    document.getElementById("identity_name").innerHTML = this.user.name;
                    if(!this.filesToUpload){
                        //REdireccion
                    }else{
                        this.makeFileRequest(this.url+ 'update-image-user/'+this.user._id,[],this.filesToUpload).then(
                            (result:any)=>{
                                this.user.image=result.image;
                                localStorage.setItem('identity',JSON.stringify(this.user));
                                
                                let image_pad = this.url+'get-image-user/'+this.user.image;
                                document.getElementById("image-logged").setAttribute('src',image_pad);
                                console.log(this.user);
                            }
                        );
                    }

                    this.alertMessage='Datos actualizados correctamente';
                }
            },
            error=>{
                var errorMessage = <any>error;
                if(errorMessage!=null){
                  var body = JSON.parse(error._body);
                  this.alertMessage=body.message;
                }
            }
        );
    }

    

    fileChangeEvent(fileInput: any){
        this.filesToUpload = <Array<File>>fileInput.target.files;
        console.log(this.filesToUpload);
    }

    makeFileRequest(url:string,params: Array<string>,files:Array<File>){
        var token = this.token;

        return new Promise(function(resolve,reject){
            var formData: any = new FormData();
            var xhr = new XMLHttpRequest();

            for(var i = 0; i<files.length;i++){
                formData.append('image',files[i],files[i].name)
            }

            xhr.onreadystatechange = function(){
                if(xhr.readyState==4){
                    if(xhr.status==200){
                        resolve(JSON.parse(xhr.response));
                    }else{
                        reject(xhr.response);
                    }
                }
            }
            xhr.open('POST',url,true);
            xhr.setRequestHeader('Authorization',token);
            xhr.send(formData);
        });
    }

    public generarToken(){
        this._userService.generarTokenTelegram(this.user,this.telegramData).subscribe(
            response=>{
                if(!response.telegramData){
                    this.alertMessage='No se ha podido generar el token, primero tienes que autorizar los mensajes desde telegram con el comando /autorizaToken';
                }else{
                    this.tokenGenerated=true;
                    this.telegramData=response.telegramData;
                    this.alertMessage='Se ha generado el token, por favor, introduzca dicho token en el campo correspondiente';
                }
            },
            error=>{
                var errorMessage = <any>error;
                if(errorMessage!=null){
                    this.alertMessage='No se ha podido generar el token, primero tienes que autorizar los mensajes desde telegram con el comando /autorizaToken';
                  //var body = JSON.parse(error._body);
                  //this.alertMessage=body.message;
                }
            }
        );
    }

    public confirmTokenTelegram(){
        this._userService.confirmTokenTelegram(this.user,this.telegramDataConfirmed).subscribe(
            response=>{
                if(!response.idAuthorizedUpdated){
                    this.alertMessage='No se ha podido generar el token';
                }else{
                    if(!response.idAuthorizedUpdated.idTelegram){
                        this.alertMessage='Ya tienes confirmado el id de telegram';
                    }else{
                        this.alertMessage='Se ha confirmado el id de telegram';
                        this.user.role='ROLE_LOCUTOR';
                        localStorage.setItem('identity',JSON.stringify(this.user));
                        localStorage.setItem('idTelegram',this.telegramData.idTelegram.toString());
                        document.getElementById("identity_telegramid").innerHTML = this.telegramData.idTelegram.toString();
                        this.tokenGenerated=false;
                        
                    }
                }
            },
            error=>{
                var errorMessage = <any>error;
                if(errorMessage!=null){
                    
                  var body = JSON.parse(error._body);
                  this.alertMessage=body.message;
                }
                console.log(error);
            }
        );
    }
}